TUI renderer — emits Rust code binding ishou colors to ratatui / crossterm Color::Rgb. Designed to be pasted into a TUI app’s theme.rs or written to a file and included via include!.
Color::Rgb
theme.rs
include!